.. _imageobjects:
.. _imageobject:

***********************
``imageObject`` Classes
***********************
This class and related sub-classes manage all the instrument-specific
images for processing by ``AstroDrizzle``.

.. inheritance-diagram:: drizzlepac.imageObject drizzlepac.acsData drizzlepac.wfc3Data drizzlepac.wfpc2Data drizzlepac.nicmosData  drizzlepac.stisData
   :parts: 2

.. toctree::
   :maxdepth: 3

   baseobjects.rst
   acsobjects.rst
   wfc3objects.rst
   stisobjects.rst
   nicmosobjects.rst
   wfpc2objects.rst

